@@ -1,10 +1,10 @@
-use shaco;
+use shaco::ingame;
 
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let client = shaco::InGameClient::new()?;
+    let client = ingame::InGameClient::new()?;
 
-    let data = client.all_game_data().await?;
+    let data = client.all_game_data(None).await?;
 
     println!("{:#?}", data);
 
